<?php

class SearchItem
{

    protected $href;
    protected $title;
    protected $description;

    public function getHref()
    {
        return $this->href;
    }

    public function getTitle()
    {
        return $this->title;
    }

    public function getDescription()
    {
        return $this->description;
    }

    public function setHref($href)
    {
        $this->href = $href;
        return $this;
    }

    public function setTitle($title)
    {
        $this->title = $title;
        return $this;
    }

    public function setDescription($description)
    {
        $this->description = $description;
        return $this;
    }

}