<?php
$this->load->library('ciext/ciext')->load_jquery_ui();
$this->js_css->parse_js('search/js/autocomplete.js');
?>
<form action="/search" method="get" id="search_form">
    <input type="text" class="search" placeholder="<?= $this->lang->line('Search') ?>" name="search_text" value="<?= $this->input->get('search_text') ?>" maxlength="60">
    <input type="submit" class="search_button">
</form>