<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * This pages will be ignored by resmng_search model
 */
$config['ignored_pages'] = array(
    '/news',
    '/photo-reports',
);
