$(function () {
    $('#search_form input[name="search_text"]').autocomplete({
        source: "/ajax/search/search_site/autocomplate",
        minLength: 3,
        select: function( event, ui ){
            $('#search_form').find('input[name="search_text"]').val(ui.item.value).end().submit();
        }
    });
});