<h1>
    <?= sprintf($this->lang->line('Upon request %s, found(%d)'), '"' . $this->input->get('search_text') . '"', count($items)) ?>
</h1>
<div class="list_news">
    <?php foreach ($items as $item) : ?>
        <div class="news_item">
            <a href="<?= $item->getHref() ?>" class="title_news"><?= $item->getTitle() ?></a>
            <?php if ($item->getDescription()) : ?>
                <p><?= $item->getDescription() ?></p>
            <?php endif; ?>
        </div>
    <?php endforeach; ?>
</div>